==> org-lsst-sal-camera-2.6.2-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry extends CameraTelemetry {
  private final boolean actruckxminus_handoffInError;

  private final boolean actruckxminus_handoffSensorValue;

  private final boolean actruckxminus_onlineInError;

  private final boolean actruckxminus_onlineSensorValue;

  private final int actruckxminus_position;

  private final boolean actruckxminus_standbyInError;

  private final boolean actruckxminus_standbySensorValue;

  private final boolean actruckxplus_handoffInError;

  private final boolean actruckxplus_handoffSensorValue;

  private final boolean actruckxplus_onlineInError;

  private final boolean actruckxplus_onlineSensorValue;

  private final int actruckxplus_position;

  private final boolean actruckxplus_standbyInError;

  private final boolean actruckxplus_standbySensorValue;

  private final boolean atHandoff;

  private final boolean atOnline;

  private final boolean atStandby;

  private final int driverPosition;

  private final int followerPosition;

  private final boolean homingDone;

  private final boolean inError;

  private final int proximityDistance;

  private final double proximityVoltage;

  public Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry(boolean actruckxminus_handoffInError,
      boolean actruckxminus_handoffSensorValue, boolean actruckxminus_onlineInError,
      boolean actruckxminus_onlineSensorValue, int actruckxminus_position,
      boolean actruckxminus_standbyInError, boolean actruckxminus_standbySensorValue,
      boolean actruckxplus_handoffInError, boolean actruckxplus_handoffSensorValue,
      boolean actruckxplus_onlineInError, boolean actruckxplus_onlineSensorValue,
      int actruckxplus_position, boolean actruckxplus_standbyInError,
      boolean actruckxplus_standbySensorValue, boolean atHandoff, boolean atOnline,
      boolean atStandby, int driverPosition, int followerPosition, boolean homingDone,
      boolean inError, int proximityDistance, double proximityVoltage) {
    this.actruckxminus_handoffInError = actruckxminus_handoffInError;
    this.actruckxminus_handoffSensorValue = actruckxminus_handoffSensorValue;
    this.actruckxminus_onlineInError = actruckxminus_onlineInError;
    this.actruckxminus_onlineSensorValue = actruckxminus_onlineSensorValue;
    this.actruckxminus_position = actruckxminus_position;
    this.actruckxminus_standbyInError = actruckxminus_standbyInError;
    this.actruckxminus_standbySensorValue = actruckxminus_standbySensorValue;
    this.actruckxplus_handoffInError = actruckxplus_handoffInError;
    this.actruckxplus_handoffSensorValue = actruckxplus_handoffSensorValue;
    this.actruckxplus_onlineInError = actruckxplus_onlineInError;
    this.actruckxplus_onlineSensorValue = actruckxplus_onlineSensorValue;
    this.actruckxplus_position = actruckxplus_position;
    this.actruckxplus_standbyInError = actruckxplus_standbyInError;
    this.actruckxplus_standbySensorValue = actruckxplus_standbySensorValue;
    this.atHandoff = atHandoff;
    this.atOnline = atOnline;
    this.atStandby = atStandby;
    this.driverPosition = driverPosition;
    this.followerPosition = followerPosition;
    this.homingDone = homingDone;
    this.inError = inError;
    this.proximityDistance = proximityDistance;
    this.proximityVoltage = proximityVoltage;
  }

  public boolean isActruckxminus_handoffInError() {
    return actruckxminus_handoffInError;
  }

  public boolean isActruckxminus_handoffSensorValue() {
    return actruckxminus_handoffSensorValue;
  }

  public boolean isActruckxminus_onlineInError() {
    return actruckxminus_onlineInError;
  }

  public boolean isActruckxminus_onlineSensorValue() {
    return actruckxminus_onlineSensorValue;
  }

  public int getActruckxminus_position() {
    return actruckxminus_position;
  }

  public boolean isActruckxminus_standbyInError() {
    return actruckxminus_standbyInError;
  }

  public boolean isActruckxminus_standbySensorValue() {
    return actruckxminus_standbySensorValue;
  }

  public boolean isActruckxplus_handoffInError() {
    return actruckxplus_handoffInError;
  }

  public boolean isActruckxplus_handoffSensorValue() {
    return actruckxplus_handoffSensorValue;
  }

  public boolean isActruckxplus_onlineInError() {
    return actruckxplus_onlineInError;
  }

  public boolean isActruckxplus_onlineSensorValue() {
    return actruckxplus_onlineSensorValue;
  }

  public int getActruckxplus_position() {
    return actruckxplus_position;
  }

  public boolean isActruckxplus_standbyInError() {
    return actruckxplus_standbyInError;
  }

  public boolean isActruckxplus_standbySensorValue() {
    return actruckxplus_standbySensorValue;
  }

  public boolean isAtHandoff() {
    return atHandoff;
  }

  public boolean isAtOnline() {
    return atOnline;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public int getDriverPosition() {
    return driverPosition;
  }

  public int getFollowerPosition() {
    return followerPosition;
  }

  public boolean isHomingDone() {
    return homingDone;
  }

  public boolean isInError() {
    return inError;
  }

  public int getProximityDistance() {
    return proximityDistance;
  }

  public double getProximityVoltage() {
    return proximityVoltage;
  }

  @Override
  public String toString() {
    return "Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry{" + "actruckxminus_handoffInError=" + actruckxminus_handoffInError +
        ", actruckxminus_handoffSensorValue=" + actruckxminus_handoffSensorValue +
        ", actruckxminus_onlineInError=" + actruckxminus_onlineInError +
        ", actruckxminus_onlineSensorValue=" + actruckxminus_onlineSensorValue +
        ", actruckxminus_position=" + actruckxminus_position +
        ", actruckxminus_standbyInError=" + actruckxminus_standbyInError +
        ", actruckxminus_standbySensorValue=" + actruckxminus_standbySensorValue +
        ", actruckxplus_handoffInError=" + actruckxplus_handoffInError +
        ", actruckxplus_handoffSensorValue=" + actruckxplus_handoffSensorValue +
        ", actruckxplus_onlineInError=" + actruckxplus_onlineInError +
        ", actruckxplus_onlineSensorValue=" + actruckxplus_onlineSensorValue +
        ", actruckxplus_position=" + actruckxplus_position +
        ", actruckxplus_standbyInError=" + actruckxplus_standbyInError +
        ", actruckxplus_standbySensorValue=" + actruckxplus_standbySensorValue +
        ", atHandoff=" + atHandoff +", atOnline=" + atOnline +", atStandby=" + atStandby +
        ", driverPosition=" + driverPosition +", followerPosition=" + followerPosition +
        ", homingDone=" + homingDone +", inError=" + inError +
        ", proximityDistance=" + proximityDistance +", proximityVoltage=" + proximityVoltage +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean actruckxminus_handoffInError;

    private boolean actruckxminus_handoffSensorValue;

    private boolean actruckxminus_onlineInError;

    private boolean actruckxminus_onlineSensorValue;

    private int actruckxminus_position;

    private boolean actruckxminus_standbyInError;

    private boolean actruckxminus_standbySensorValue;

    private boolean actruckxplus_handoffInError;

    private boolean actruckxplus_handoffSensorValue;

    private boolean actruckxplus_onlineInError;

    private boolean actruckxplus_onlineSensorValue;

    private int actruckxplus_position;

    private boolean actruckxplus_standbyInError;

    private boolean actruckxplus_standbySensorValue;

    private boolean atHandoff;

    private boolean atOnline;

    private boolean atStandby;

    private int driverPosition;

    private int followerPosition;

    private boolean homingDone;

    private boolean inError;

    private int proximityDistance;

    private double proximityVoltage;

    private Builder() {
    }

    public Builder actruckxminus_handoffInError(boolean actruckxminus_handoffInError) {
      this.actruckxminus_handoffInError = actruckxminus_handoffInError;
      return this;
    }

    public Builder actruckxminus_handoffSensorValue(boolean actruckxminus_handoffSensorValue) {
      this.actruckxminus_handoffSensorValue = actruckxminus_handoffSensorValue;
      return this;
    }

    public Builder actruckxminus_onlineInError(boolean actruckxminus_onlineInError) {
      this.actruckxminus_onlineInError = actruckxminus_onlineInError;
      return this;
    }

    public Builder actruckxminus_onlineSensorValue(boolean actruckxminus_onlineSensorValue) {
      this.actruckxminus_onlineSensorValue = actruckxminus_onlineSensorValue;
      return this;
    }

    public Builder actruckxminus_position(int actruckxminus_position) {
      this.actruckxminus_position = actruckxminus_position;
      return this;
    }

    public Builder actruckxminus_standbyInError(boolean actruckxminus_standbyInError) {
      this.actruckxminus_standbyInError = actruckxminus_standbyInError;
      return this;
    }

    public Builder actruckxminus_standbySensorValue(boolean actruckxminus_standbySensorValue) {
      this.actruckxminus_standbySensorValue = actruckxminus_standbySensorValue;
      return this;
    }

    public Builder actruckxplus_handoffInError(boolean actruckxplus_handoffInError) {
      this.actruckxplus_handoffInError = actruckxplus_handoffInError;
      return this;
    }

    public Builder actruckxplus_handoffSensorValue(boolean actruckxplus_handoffSensorValue) {
      this.actruckxplus_handoffSensorValue = actruckxplus_handoffSensorValue;
      return this;
    }

    public Builder actruckxplus_onlineInError(boolean actruckxplus_onlineInError) {
      this.actruckxplus_onlineInError = actruckxplus_onlineInError;
      return this;
    }

    public Builder actruckxplus_onlineSensorValue(boolean actruckxplus_onlineSensorValue) {
      this.actruckxplus_onlineSensorValue = actruckxplus_onlineSensorValue;
      return this;
    }

    public Builder actruckxplus_position(int actruckxplus_position) {
      this.actruckxplus_position = actruckxplus_position;
      return this;
    }

    public Builder actruckxplus_standbyInError(boolean actruckxplus_standbyInError) {
      this.actruckxplus_standbyInError = actruckxplus_standbyInError;
      return this;
    }

    public Builder actruckxplus_standbySensorValue(boolean actruckxplus_standbySensorValue) {
      this.actruckxplus_standbySensorValue = actruckxplus_standbySensorValue;
      return this;
    }

    public Builder atHandoff(boolean atHandoff) {
      this.atHandoff = atHandoff;
      return this;
    }

    public Builder atOnline(boolean atOnline) {
      this.atOnline = atOnline;
      return this;
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder driverPosition(int driverPosition) {
      this.driverPosition = driverPosition;
      return this;
    }

    public Builder followerPosition(int followerPosition) {
      this.followerPosition = followerPosition;
      return this;
    }

    public Builder homingDone(boolean homingDone) {
      this.homingDone = homingDone;
      return this;
    }

    public Builder inError(boolean inError) {
      this.inError = inError;
      return this;
    }

    public Builder proximityDistance(int proximityDistance) {
      this.proximityDistance = proximityDistance;
      return this;
    }

    public Builder proximityVoltage(double proximityVoltage) {
      this.proximityVoltage = proximityVoltage;
      return this;
    }

    public Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry build() {
      return new Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry(actruckxminus_handoffInError, actruckxminus_handoffSensorValue, actruckxminus_onlineInError, actruckxminus_onlineSensorValue, actruckxminus_position, actruckxminus_standbyInError, actruckxminus_standbySensorValue, actruckxplus_handoffInError, actruckxplus_handoffSensorValue, actruckxplus_onlineInError, actruckxplus_onlineSensorValue, actruckxplus_position, actruckxplus_standbyInError, actruckxplus_standbySensorValue, atHandoff, atOnline, atStandby, driverPosition, followerPosition, homingDone, inError, proximityDistance, proximityVoltage);
    }
  }
}

==> org-lsst-sal-camera-3.0.2-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry extends CameraTelemetry {
  private final boolean actruckxminus_handoffInError;

  private final boolean actruckxminus_handoffSensorValue;

  private final boolean actruckxminus_onlineInError;

  private final boolean actruckxminus_onlineSensorValue;

  private final boolean actruckxminus_standbyInError;

  private final boolean actruckxminus_standbySensorValue;

  private final boolean actruckxplus_handoffInError;

  private final boolean actruckxplus_handoffSensorValue;

  private final boolean actruckxplus_onlineInError;

  private final boolean actruckxplus_onlineSensorValue;

  private final boolean actruckxplus_standbyInError;

  private final boolean actruckxplus_standbySensorValue;

  private final boolean atHandoff;

  private final boolean atOnline;

  private final boolean atStandby;

  private final int driverPosition;

  private final int followerPosition;

  private final boolean homingDone;

  private final boolean inError;

  private final int proximityDistance;

  private final double proximityVoltage;

  public Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry(boolean actruckxminus_handoffInError,
      boolean actruckxminus_handoffSensorValue, boolean actruckxminus_onlineInError,
      boolean actruckxminus_onlineSensorValue, boolean actruckxminus_standbyInError,
      boolean actruckxminus_standbySensorValue, boolean actruckxplus_handoffInError,
      boolean actruckxplus_handoffSensorValue, boolean actruckxplus_onlineInError,
      boolean actruckxplus_onlineSensorValue, boolean actruckxplus_standbyInError,
      boolean actruckxplus_standbySensorValue, boolean atHandoff, boolean atOnline,
      boolean atStandby, int driverPosition, int followerPosition, boolean homingDone,
      boolean inError, int proximityDistance, double proximityVoltage) {
    this.actruckxminus_handoffInError = actruckxminus_handoffInError;
    this.actruckxminus_handoffSensorValue = actruckxminus_handoffSensorValue;
    this.actruckxminus_onlineInError = actruckxminus_onlineInError;
    this.actruckxminus_onlineSensorValue = actruckxminus_onlineSensorValue;
    this.actruckxminus_standbyInError = actruckxminus_standbyInError;
    this.actruckxminus_standbySensorValue = actruckxminus_standbySensorValue;
    this.actruckxplus_handoffInError = actruckxplus_handoffInError;
    this.actruckxplus_handoffSensorValue = actruckxplus_handoffSensorValue;
    this.actruckxplus_onlineInError = actruckxplus_onlineInError;
    this.actruckxplus_onlineSensorValue = actruckxplus_onlineSensorValue;
    this.actruckxplus_standbyInError = actruckxplus_standbyInError;
    this.actruckxplus_standbySensorValue = actruckxplus_standbySensorValue;
    this.atHandoff = atHandoff;
    this.atOnline = atOnline;
    this.atStandby = atStandby;
    this.driverPosition = driverPosition;
    this.followerPosition = followerPosition;
    this.homingDone = homingDone;
    this.inError = inError;
    this.proximityDistance = proximityDistance;
    this.proximityVoltage = proximityVoltage;
  }

  public boolean isActruckxminus_handoffInError() {
    return actruckxminus_handoffInError;
  }

  public boolean isActruckxminus_handoffSensorValue() {
    return actruckxminus_handoffSensorValue;
  }

  public boolean isActruckxminus_onlineInError() {
    return actruckxminus_onlineInError;
  }

  public boolean isActruckxminus_onlineSensorValue() {
    return actruckxminus_onlineSensorValue;
  }

  public boolean isActruckxminus_standbyInError() {
    return actruckxminus_standbyInError;
  }

  public boolean isActruckxminus_standbySensorValue() {
    return actruckxminus_standbySensorValue;
  }

  public boolean isActruckxplus_handoffInError() {
    return actruckxplus_handoffInError;
  }

  public boolean isActruckxplus_handoffSensorValue() {
    return actruckxplus_handoffSensorValue;
  }

  public boolean isActruckxplus_onlineInError() {
    return actruckxplus_onlineInError;
  }

  public boolean isActruckxplus_onlineSensorValue() {
    return actruckxplus_onlineSensorValue;
  }

  public boolean isActruckxplus_standbyInError() {
    return actruckxplus_standbyInError;
  }

  public boolean isActruckxplus_standbySensorValue() {
    return actruckxplus_standbySensorValue;
  }

  public boolean isAtHandoff() {
    return atHandoff;
  }

  public boolean isAtOnline() {
    return atOnline;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public int getDriverPosition() {
    return driverPosition;
  }

  public int getFollowerPosition() {
    return followerPosition;
  }

  public boolean isHomingDone() {
    return homingDone;
  }

  public boolean isInError() {
    return inError;
  }

  public int getProximityDistance() {
    return proximityDistance;
  }

  public double getProximityVoltage() {
    return proximityVoltage;
  }

  @Override
  public String toString() {
    return "Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry{" + "actruckxminus_handoffInError=" + actruckxminus_handoffInError +
        ", actruckxminus_handoffSensorValue=" + actruckxminus_handoffSensorValue +
        ", actruckxminus_onlineInError=" + actruckxminus_onlineInError +
        ", actruckxminus_onlineSensorValue=" + actruckxminus_onlineSensorValue +
        ", actruckxminus_standbyInError=" + actruckxminus_standbyInError +
        ", actruckxminus_standbySensorValue=" + actruckxminus_standbySensorValue +
        ", actruckxplus_handoffInError=" + actruckxplus_handoffInError +
        ", actruckxplus_handoffSensorValue=" + actruckxplus_handoffSensorValue +
        ", actruckxplus_onlineInError=" + actruckxplus_onlineInError +
        ", actruckxplus_onlineSensorValue=" + actruckxplus_onlineSensorValue +
        ", actruckxplus_standbyInError=" + actruckxplus_standbyInError +
        ", actruckxplus_standbySensorValue=" + actruckxplus_standbySensorValue +
        ", atHandoff=" + atHandoff +", atOnline=" + atOnline +", atStandby=" + atStandby +
        ", driverPosition=" + driverPosition +", followerPosition=" + followerPosition +
        ", homingDone=" + homingDone +", inError=" + inError +
        ", proximityDistance=" + proximityDistance +", proximityVoltage=" + proximityVoltage +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean actruckxminus_handoffInError;

    private boolean actruckxminus_handoffSensorValue;

    private boolean actruckxminus_onlineInError;

    private boolean actruckxminus_onlineSensorValue;

    private boolean actruckxminus_standbyInError;

    private boolean actruckxminus_standbySensorValue;

    private boolean actruckxplus_handoffInError;

    private boolean actruckxplus_handoffSensorValue;

    private boolean actruckxplus_onlineInError;

    private boolean actruckxplus_onlineSensorValue;

    private boolean actruckxplus_standbyInError;

    private boolean actruckxplus_standbySensorValue;

    private boolean atHandoff;

    private boolean atOnline;

    private boolean atStandby;

    private int driverPosition;

    private int followerPosition;

    private boolean homingDone;

    private boolean inError;

    private int proximityDistance;

    private double proximityVoltage;

    private Builder() {
    }

    public Builder actruckxminus_handoffInError(boolean actruckxminus_handoffInError) {
      this.actruckxminus_handoffInError = actruckxminus_handoffInError;
      return this;
    }

    public Builder actruckxminus_handoffSensorValue(boolean actruckxminus_handoffSensorValue) {
      this.actruckxminus_handoffSensorValue = actruckxminus_handoffSensorValue;
      return this;
    }

    public Builder actruckxminus_onlineInError(boolean actruckxminus_onlineInError) {
      this.actruckxminus_onlineInError = actruckxminus_onlineInError;
      return this;
    }

    public Builder actruckxminus_onlineSensorValue(boolean actruckxminus_onlineSensorValue) {
      this.actruckxminus_onlineSensorValue = actruckxminus_onlineSensorValue;
      return this;
    }

    public Builder actruckxminus_standbyInError(boolean actruckxminus_standbyInError) {
      this.actruckxminus_standbyInError = actruckxminus_standbyInError;
      return this;
    }

    public Builder actruckxminus_standbySensorValue(boolean actruckxminus_standbySensorValue) {
      this.actruckxminus_standbySensorValue = actruckxminus_standbySensorValue;
      return this;
    }

    public Builder actruckxplus_handoffInError(boolean actruckxplus_handoffInError) {
      this.actruckxplus_handoffInError = actruckxplus_handoffInError;
      return this;
    }

    public Builder actruckxplus_handoffSensorValue(boolean actruckxplus_handoffSensorValue) {
      this.actruckxplus_handoffSensorValue = actruckxplus_handoffSensorValue;
      return this;
    }

    public Builder actruckxplus_onlineInError(boolean actruckxplus_onlineInError) {
      this.actruckxplus_onlineInError = actruckxplus_onlineInError;
      return this;
    }

    public Builder actruckxplus_onlineSensorValue(boolean actruckxplus_onlineSensorValue) {
      this.actruckxplus_onlineSensorValue = actruckxplus_onlineSensorValue;
      return this;
    }

    public Builder actruckxplus_standbyInError(boolean actruckxplus_standbyInError) {
      this.actruckxplus_standbyInError = actruckxplus_standbyInError;
      return this;
    }

    public Builder actruckxplus_standbySensorValue(boolean actruckxplus_standbySensorValue) {
      this.actruckxplus_standbySensorValue = actruckxplus_standbySensorValue;
      return this;
    }

    public Builder atHandoff(boolean atHandoff) {
      this.atHandoff = atHandoff;
      return this;
    }

    public Builder atOnline(boolean atOnline) {
      this.atOnline = atOnline;
      return this;
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder driverPosition(int driverPosition) {
      this.driverPosition = driverPosition;
      return this;
    }

    public Builder followerPosition(int followerPosition) {
      this.followerPosition = followerPosition;
      return this;
    }

    public Builder homingDone(boolean homingDone) {
      this.homingDone = homingDone;
      return this;
    }

    public Builder inError(boolean inError) {
      this.inError = inError;
      return this;
    }

    public Builder proximityDistance(int proximityDistance) {
      this.proximityDistance = proximityDistance;
      return this;
    }

    public Builder proximityVoltage(double proximityVoltage) {
      this.proximityVoltage = proximityVoltage;
      return this;
    }

    public Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry build() {
      return new Fcs_Autochanger_AutochangerTrucks_TrendingTelemetry(actruckxminus_handoffInError, actruckxminus_handoffSensorValue, actruckxminus_onlineInError, actruckxminus_onlineSensorValue, actruckxminus_standbyInError, actruckxminus_standbySensorValue, actruckxplus_handoffInError, actruckxplus_handoffSensorValue, actruckxplus_onlineInError, actruckxplus_onlineSensorValue, actruckxplus_standbyInError, actruckxplus_standbySensorValue, atHandoff, atOnline, atStandby, driverPosition, followerPosition, homingDone, inError, proximityDistance, proximityVoltage);
    }
  }
}
